==> jc-1.4.0.tar.gz: java/security/Permissions__242.h <==
// final class java.security.Permissions$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8af9c572cabbf916 java_security_Permissions__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_Permissions__242_H_
#define _JC_java_security_Permissions__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_Permissions$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_Permissions__242$sub_refs	_jc_java_security_Permissions__242$sub_refs;
typedef struct _jc_java_security_Permissions__242$sub_nonrefs	_jc_java_security_Permissions__242$sub_nonrefs;
typedef struct _jc_java_security_Permissions__242$refs	_jc_java_security_Permissions__242$refs;
typedef struct _jc_java_security_Permissions__242$nonrefs	_jc_java_security_Permissions__242$nonrefs;
typedef struct _jc_java_security_Permissions__242$object	_jc_java_security_Permissions__242$object;

typedef const struct _jc_java_security_Permissions__242$vmethods	_jc_java_security_Permissions__242$vmethods;
typedef const struct _jc_java_security_Permissions__242$vtable	_jc_java_security_Permissions__242$vtable;
typedef const struct _jc_java_security_Permissions__242$vtype	_jc_java_security_Permissions__242$vtype;

// Constructors
extern void _jc_java_security_Permissions__242$method$_init$c6d41ce994429d01(_jc_env *, struct _jc_java_security_Permissions__242$object *, struct _jc_java_security_Permissions$object *);

// Virtual methods
extern jboolean _jc_java_security_Permissions__242$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_security_Permissions__242$object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_Permissions__242$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_security_Permissions__242$object *);
extern void _jc_java_security_Permissions__242$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Permissions__242$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_Permissions__242$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_security_Permissions__242$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_security_Permissions__242$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_Permissions__242$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_security_Permissions__242$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_security_Permissions__242$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Permissions__242$object *);
};

// Vtable
struct _jc_java_security_Permissions__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permissions__242$vmethods	java_security_Permissions__242;
};

// Vtype
struct _jc_java_security_Permissions__242$vtype {
	_jc_type			type;
	_jc_java_security_Permissions__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Permissions__242$sub_refs {
	struct _jc_object	*main__5fenum;
	struct _jc_object	*sub__5fenum;
	struct _jc_java_security_Permissions$object	*this;
};

// Reference instance fields (object)
struct _jc_java_security_Permissions__242$refs {
    _jc_java_security_Permissions__242$sub_refs	java_security_Permissions__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Permissions__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Permissions__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permissions__242$sub_nonrefs	java_security_Permissions__242;
};

// Object instance structure
struct _jc_java_security_Permissions__242$object {
	_jc_java_security_Permissions__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Permissions__242$vtype	*vtype;
	_jc_java_security_Permissions__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Permissions__242$vtype _jc_java_security_Permissions__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Permissions__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Permissions__242$class_object;

#endif	/* _JC_java_security_Permissions__242_H_ */

==> jc-1.4.6.tar.gz: java/security/Permissions__242.h <==
// final class java.security.Permissions$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8af9c572cabbf916 java_security_Permissions__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_Permissions__242_H_
#define _JC_java_security_Permissions__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_Permissions$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_Permissions__242$sub_refs	_jc_java_security_Permissions__242$sub_refs;
typedef struct _jc_java_security_Permissions__242$sub_nonrefs	_jc_java_security_Permissions__242$sub_nonrefs;
typedef struct _jc_java_security_Permissions__242$refs	_jc_java_security_Permissions__242$refs;
typedef struct _jc_java_security_Permissions__242$nonrefs	_jc_java_security_Permissions__242$nonrefs;
typedef struct _jc_java_security_Permissions__242$object	_jc_java_security_Permissions__242$object;

typedef const struct _jc_java_security_Permissions__242$vmethods	_jc_java_security_Permissions__242$vmethods;
typedef const struct _jc_java_security_Permissions__242$vtable	_jc_java_security_Permissions__242$vtable;
typedef const struct _jc_java_security_Permissions__242$vtype	_jc_java_security_Permissions__242$vtype;

// Constructors
extern void _jc_java_security_Permissions__242$method$_init$c6d41ce994429d01(_jc_env *, struct _jc_java_security_Permissions__242$object *, struct _jc_java_security_Permissions$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_Permissions__242$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_Permissions__242$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_Permissions__242$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_Permissions__242$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_security_Permissions__242$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_security_Permissions__242$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_Permissions__242$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_Permissions__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_Permissions__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permissions__242$vmethods	java_security_Permissions__242;
};

// Vtype
struct _jc_java_security_Permissions__242$vtype {
	_jc_type			type;
	_jc_java_security_Permissions__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_Permissions__242$sub_refs {
	struct _jc_object	*main__5fenum;
	struct _jc_object	*sub__5fenum;
	struct _jc_java_security_Permissions$object	*this;
};

// Reference instance fields (object)
struct _jc_java_security_Permissions__242$refs {
    _jc_java_security_Permissions__242$sub_refs	java_security_Permissions__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_Permissions__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_Permissions__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permissions__242$sub_nonrefs	java_security_Permissions__242;
};

// Object instance structure
struct _jc_java_security_Permissions__242$object {
	_jc_java_security_Permissions__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_Permissions__242$vtype	*vtype;
	_jc_java_security_Permissions__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_Permissions__242$vtype _jc_java_security_Permissions__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_Permissions__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_Permissions__242$class_object;

#endif	/* _JC_java_security_Permissions__242_H_ */
